---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the bug**
<!-- A clear and concise description of what the bug is. (If what you are experiencing is NOT a bug but instead a support issue, please open a Discussion instead!) -->

**To Reproduce**

Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
<!-- A clear and concise description of what you expected to happen. -->

**Screenshots**
<!-- If applicable, add screenshots to help explain your problem. -->

**Desktop**
<!-- Please complete the following information. -->

- OS: <!-- e.g. Linux -->
- OS Version/Flavor: <!-- e.g. CentOS 7.2 -->
- CPU: <!-- e.g. Intel Xeon 8175M -->

**Additional context**
<!-- Add any other context about the problem here. -->
